#!/usr/local/bin/perl

require 'getopts.pl';

use Oraperl;

# ***************************************************
# Get registration fieldnames, lengths, types
# ***************************************************
sub reg_table 
{
   $csrreg = &ora_open($lda, $GET_USER_REG);
   @reg_fldname   = &ora_titles($csrreg);
   @reg_fldlength = &ora_lengths($csrreg);
   @reg_fldtype   = &ora_types($csrreg);
   $num_regflds   = $#reg_fldname;
   print "number of registration fields is $num_regfields<BR>\n";

   &print_reg_table;  #use only for testing
   &ora_close($csrreg);

}
# ***************************************************
#  Print registration db fieldnames, lengths
# ***************************************************
sub print_reg_table
{
   print "<TABLE BORDER=2>\n";
   print "<TR><TD>Index</TD><TD>FieldName</TD><TD>Length</TD><TD>DataType</TD>";
   print "<TD>Assoc. L</TD></TR> \n";
   for ($i=0; $i<= $num_regflds; $i++)
   {
      $flen {$reg_fldname[$i]} = $reg_fldlength[$i];
      $ftype {$reg_fldname[$i]} = $reg_fldtype[$i];
      print "<TR>\n";
      print "<TD>$i</TD><TD>$reg_fldname[$i]</TD><TD>$reg_fldlength[$i]</TD>";
      print "<TD>$reg_fldtype[$i]</TD><TD>$flen{$reg_fldname[$i]}</TD>\n";
      print "</TR>\n";
   }
   print "</TABLE>\n";
}

# ***************************************************
# Check input from form and record input errors
# ***************************************************
sub check_for_errors
{

   $CHECK_USERNAME = 
                 "SELECT username FROM user_reg
                   WHERE username = :1";

   $inputerror_rf = 0;
   $inputerror_un = 0;
   $miscerrors    = 0;
   $uname_error   = 0;

#  required fields: 
#  $user_fname, $user_lname, ($address1 OR $address2), 
#  $city, $state, $postal_code, (?? $country)
# -----------------------------------------------------------------
   if( $user_fname eq  "n") { $inputerror_rf++;} 
   if( $user_lname eq  "n") { $inputerror_rf++;} 
   if(($address1 eq    "n") && ($address2 eq "n") ) { $inputerror_rf++; } 
   if( $city eq        "n") { $inputerror_rf++;} 
   if( $state eq       "n") { $inputerror_rf++;} 
   if( $postal_code eq "n") { $inputerror_rf++;} 
#  if( $user_phone eq  "n") { $inputerror_rf++;} 

   if ( ($ltcom_req eq "n") && ($com_req eq "n") 
     && ($res_req  eq "n")  && ($ptac_req eq "n") )
   {
      $inputerror_pkgsel = 1;
   }

# if username is required, check name entered for uniqueness
# ----------------------------------------------------------
   $deblank = $username;
   $deblank =~ s/ //g;
   $lenuname = length($username); 
   $lendeblank = length($deblank);

   if ($username eq "n") 
   {  
      $inputerror_un = 1;
   } 
   elsif ( ($lenuname < 6)  || ($lenuname > 15)  )  
   {
      $inputerror_un = 2;
      &write_comment("username is $lenuname characters");
   }
  #   elsif (username contains non alphan characters)
   elsif ($lendeblank < $lenuname)
   {
       $inputerror_un = 5;
       &write_comment("username is $lenuname chars, 
          without blanks is $lendeblank chars");
   }
   else 
   {
      $csruname = &ora_open($lda, $CHECK_USERNAME);
      &ora_bind ($csruname, $username);
      ($dbusername) = &ora_fetch($csruname);
      if ($dbusername eq $username)   
      { 
         $inputerror_un = 3; 
         &write_comment("fetched  $dbusername from the database");
      }
      &ora_close($csruname);
   }

# Check that entered data does not exceed database field length
# -------------------------------------------------------------
   for ($ii=0; $ii <= $#reg_fldname; $ii++) { $flenerror[$ii]  = 0;}

   $explanation = 'and could not be entered in the database.';
   $ilt = 'is longer than';
   $ierr = 0;
   for ($ii=0; $ii <= $#reg_fldname; $ii++)
   {
      if( ($reg_fldname[$ii]   eq 'USER_FNAME')
        && (length($user_fname)  >  $reg_fldlength[$ii]) ) {
          $errstr[$ierr] = 'FIRST NAME $user_fname $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if (($reg_fldname[$ii]  eq 'USER_LNAME')
       && (length($user_lname) > $reg_fldlength[$ii]) ) {
          $errstr[$ierr] = 'LAST NAME $user_lname $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'USER_TITLE') && (length($user_title)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'TITLE $user_title $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'COMPANY') && (length($company)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'COMPANY $company $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'ADDRESS1') && (length($address1)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'ADDRESS LINE 1 $address1 $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'ADDRESS2') && (length($address2)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'ADDRESS LINE 2 $address2 $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if (($reg_fldname[$ii] eq 'CITY') && (length($city)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'CITY $city $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'STATE') && (length($state)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'STATE $state $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'POSTAL_CODE') 
       && (length($postal_code)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'POSTAL CODE $postal_code $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'COUNTRY') && (length($country)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'COUNTRY $country $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'COMPANY_URL') && (length($company_url)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'COMPANY_URL $company_url $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'USER_PHONE') && (length($user_phone) >$reg_fldlength[$ii])) {
          $errstr[$ierr] = "USER_PHONE $user_phone $ilt $reg_fldlength[$ii] $explanation";
    #     $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'USER_FAX') && (length($user_fax)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'USER FAX $user_fax $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'USER_EMAIL') && (length($user_email)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'USER EMAIL $user_email $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'CONTACT_NAME') 
       && (length($contact_name)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'CONTACT NAME $contact_name $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'CONTACT_COMPANY') 
       && (length($contact_company)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'CONTACT_COMPANY $contact_company $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'CONTACT_PHONE') 
       && (length($contact_phone)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'CONTACT PHONE $contact_phone $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'CONTACT_FAX') 
       && (length($contact_fax)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'CONTACT FAX $contact_fax $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'CONTACT_EMAIL') 
       && (length($contact_email)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'CONTACT EMAIL $contact_email $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }
      if(($reg_fldname[$ii] eq 'CONTACT_LOCATION') 
       && (length($contact_location)>$reg_fldlength[$ii])) {
          $errstr[$ierr] = 'CONTACT LOCATION $contact_location $ilt $reg_fldlength[$ii] $explanation';
          $flenerror[$ii] =1; $ierr++; 
      }

   }     
}

# ***************************************************
# check input item for length & null (not used)
# ***************************************************
sub check_input_item
{
    $lenerror  = 0;
    $nullerror = 0;
    local ($item, $len, $lenerror, $req, $nullerror) = @_;
    if (length($item) > $len ) { $lenerror = 1; }
    if ( ($req == 1) && ( ($item eq "n") || ($item eq "0") ) ) {$nullerror =1; }
}

# ***************************************************
# print error form
# ***************************************************
sub print_error_form
{

   $img  = "nao_media/register.jpg";
   print "<P><BR>\n";
   print "<UL>\n";
   print "<TABLE CELLSPACING=15 BORDER=0>\n";
   print "<TR><TD>\n";
   print "<IMG SRC=\"$docpath$img\" WIDTH=200 HEIGHT=120 BORDER=0>\n";
   print "</TD><TD ALIGN+CENTER>\n";
   print "<FONT SIZE=4>\n";
   print "<B>Please Edit Your <BR>Registration Information</B></FONT>\n";
   print "</TD></TR>\n";
   print "</TABLE>\n";

   print "There were errors in the information you entered into the \n";
   print "Preferred Access Registration Form. Review the error message(s) below,\n";
   print "return to your form for corrections by using your browser's \"Back\" \n";
   print "or \"Back in Frame\" \n";
   print "function and resubmit your request.\n";
   print "<P><P>\n";

  if ($inputerror_rf > 0) { 
     &print_null_input($inputerror_rf); 
     print "<P>\n";
  }

  if ($inputerror_un > 0) { 
     &print_username_error($inputerror_un); 
     print "<P>\n";
  }
  
  if ($inputerror_pkgsel > 0) { 
     &print_package_selection_error($inputerror_pkgsel); 
     print "<P>\n";
  }
  
  if ($ierr > 0) { 
     &print_fieldlength_errors (@flenerror); 
     print "</UL>\n";
  }

}

# ***************************************************
#  verbiage to user about nulls in required fields
# ***************************************************
sub print_null_input
{
  print "<B>Required Fields:</B><P>\n";
  print "<UL>\n";
  print "All input fields indicated with a \"*\" \n";
  print "must contain an entry.\n"; 
  print "</UL>\n";
}

# ***************************************************
#  verbiage to user about errors in username input
# ***************************************************
sub print_username_error
{
# print "<B>There was an error in the input of the username field:</B><P>\n";
# print "<UL>\n";
  if ($inputerror_un == 1)
  {
     print "<B>Username: </B><P>\n";
     print "<UL>\n";
     print "The entry of a User Name is required and must adhere to the\n";
     print "characteristics for size and content as indicated in the form.\n";
     print "</UL>\n";
  }
  if ($inputerror_un == 2)
  {
     print "<B>Username: </B><P>\n";
     print "<UL>\n";
     print "The entry of a User Name is required and must adhere to the\n";
     print "characteristics for size and content as indicated in the form.\n";
     print "</UL>\n";
  }
  if ($inputerror_un == 3)
  {
     print "<B>Duplicate User Name:</B><P>\n";
     print "<UL>\n";
     print "The User Name you requested has already been assigned. Modify or\n";
     print "choose a different name adhering to the characteristics for size\n";
     print "and content as indicated in the form.\n";
     print "</UL>\n";
  }
  if ($inputerror_un == 5)
  {
     print "<B>Blank Spaces In User Name:</B><P>\n";
     print "<UL>\n";
     print "The User Name you requested contains one or more blanks. Please modify or\n";
     print "choose a different name adhering to the characteristics for size\n";
     print "and content as indicated in the form.\n";
     print "</UL>\n";
  }
}


# ***************************************************
#  verbiage to user about errors in username input
# ***************************************************
sub print_package_selection_error
{
  if( $inputerror_pkgsel == 1 ) 
  {
     print "<B>Product and Service Selections:</B><P>\n";
     print "<UL>\n";

     print "At least one Product and/or Services Description must be selected.\n";
     print "</UL>\n";
  }
}

# ***************************************************
#  verbiage to user about errors in input fieldlength 
# ***************************************************
sub print_fieldlength_errors
{
   print "<B>Input items that are too long for the database:</B><P>\n";
   print "<UL>\n";
   for ($iprt=0; $iprt <= $#errstr; $iprt++)
   {
      print "$errstr[$iprt]<BR>\n";
   }
   print "</UL>\n";
}

# ***************************************************
# Process the input data and fill derived fields
#
# 17sep96  changed all commercial req "on" values to "y"
#          changed res_req "on" value to "a"
# ***************************************************
sub process_input_data
{
# Change the values of the product request check-boxes
# ---------------------------------------------------
#  if ($com_req eq "on")   { $com_req = "y"; }
#  if ($ltcom_req eq "on") { $ltcom_req = "y"; }
#  if ($ptac_req eq "on")  { $ptac_req = "y"; }
#  if ($res_req eq "on")   { $res_req = "a"; }


# Set access permission, status and password fields
# -------------------------------------------

   $commreq = "n";
#  if ( ($com_req eq "y") || ($ptac_req eq "y") || ($ltcom_req eq "y") ) 
#  {
#     $commreq = "y";
#  }

   if ( ($res_req eq "a") && ($commreq ne "y") ) 
   {
      $userstat = "A";
      $userpm   = ":H1";   #new
      $userpw   = $username;
   }
   if ( ($res_req eq "a") && ($commreq eq "y") )
   {
      $userstat = "P";
      $userpm   = ":H1";   #new
      $userpw   = $username;
   }
   if ( ($res_req ne "a") && ($commreq eq "y") )
   {
      $userstat = "P";
      $userpm   = "n";
      $userpw   = "n";
   }
   if ( length($userpw) > 8 )
   {
      $userpw = substr($userpw, 0, 8);
   }

# Process phone number to get pure numerical version            #new
#   for update comparisions
# --------------------------------------------------

   $user_phone_num = $user_phone;
   $user_phone_num =~ s/ //g;
   $user_phone_num =~ s/-//g;
   $user_phone_num =~ s/_//g;
   $user_phone_num =~ s/\(//g;
   $user_phone_num =~ s/\)//g;
   $user_phone_num =~ s/\.//g;
   $user_phone_num =~ s/\///g;
   $user_phone_num =~ s/[a-z][A-Z]*/0/g;
   if (length($user_phone_num) == 0) {$user_phone_num = undef; }

   &write_comment("$user_phone converts to $user_phone_num; ext is $user_phone_ext1\n");

}

# ***************************************************
# Store record
# ***************************************************
sub store_record
{
#  print "<BR>Start of subroutine store_record<BR>\n";

   $GET_RECORD_ID =
             "SELECT MAX(record_id) FROM user_reg";

   $csrrec = &ora_open($lda, $GET_RECORD_ID) 
          || print "failed to open $GET_RECORD_ID<BR>\n";
   ($recid) = &ora_fetch($csrrec);
    $record_id = $recid +1;

#  print "<BR>record_id for new record is $record_id<BR>\n";
   &ora_close($csrrec);

   $csrstore = &ora_open($lda, $INSERT_USER_REG) 
               || print "failed to open $INSERT_USER_REG<BR>\n";


   &write_comment("Data values just before binding to cursor and storing record");
   print "<P>\n";
#  &print_data_values;
   
   $bindstatus = &ora_bind ($csrstore, 
            $record_id,        $userpw,            $username,       $user_fname,    
            $user_lname,       $user_title,        $userstat,       $userpm, 
            $company,          $address1,          $address2,       $city,
            $state,            $region,            $zip_code5,      $zip_code4,
            $postal_code,      $country,           $company_url,    $user_phone,
            $user_fax,         $user_email,        $contact_id,     $contact_name,
            $contact_company,  $contact_phone,     $contact_fax,    $contact_email,
            $contact_location, $email_ok,          $ptac_req,       $ltcom_req,
            $res_req,          $com_req,           $reg_date,       $user_phone_ext1,
            $user_phone_num
            );

   &write_comment("bind status for csrstore is $bindstatus");
   &ora_close($csrstore);
  
   &write_comment("finished storing record with record_id $record_id\n"); #new
   &ora_commit($lda);
}

# ***************************************************
# Check stored record
# ***************************************************
sub check_stored_record
{

   $csrcheck = &ora_open($lda,  $GET_PART_RECORD) 
                    || die "failed to open $GET_PART_RECORD<BR>\n";  
   &ora_bind($csrcheck, $record_id);
   ($recid, $uname, $ufname, $ulname) = &ora_fetch($csrcheck);
   print "<P><HR><P>\n";
   print "Retrieved the following record which was just stored:<BR>\n";
   print "record_id is $recid, username $uname, name is $ufname $ulname<BR>\n";
   &ora_close($csrcheck);

}

# *****************************************************
# Get entire stored record: to confirm success to user 
# *****************************************************
sub get_stored_record
{

   $csrd = &ora_open($lda,  $GET_WHOLE_RECORD) 
                    || die "failed to open $GET_WHOLE_RECORD<BR>\n";  
   &ora_bind($csrd, $record_id);
   (@newrec) = &ora_fetch($csrd);
   @printrec = @newrec;
   &write_comment("After retrieve of stored record, if ($printrec[0]) >0, store user_ip info\n");

   if ( $printrec[0] > 0 ) { &store_user_ip; }  # comment out for testing
   if ( $printrec[0] = 0 ) { }
}

# *****************************************************
# On successful registration, store the user_ip info
# *****************************************************
sub store_user_ip
{

   $query_string  = $ENV{'QUERY_STRING'};
   $remote_host   = $ENV{'REMOTE_HOST'};
   $remote_user   = $ENV{'REMOTE_USER'};
   $remote_addr   = $ENV{'REMOTE_ADDR'};
   $client_agent  = $ENV{'HTTP_USER_AGENT'};
   $client_ident  = $ENV{'REMOTE_IDENT'};
   $user_os       = "n";
   $user_win      = "n";
   $user_browser  = "n";

   
   open (REGPRBUF, ">>$reg_prbuffer") 
       || print "<BR>Failed to open $reg_prbuffer for append<BR>\n";   #dv
   print REGPRBUF "remote host is $remote_host<BR>\n";   #dv
   print REGPRBUF "remote user is $remote_user<BR>\n";   #dv
   print REGPRBUF "remote address is $remote_addr<BR>\n";   #dv
   print REGPRBUF "client agent is $client_agent<BR>\n";   #dv
   print REGPRBUF "client ident is $client_ident<BR>\n";   #dv
   print REGPRBUF "username is $username<BR>\n";   #dv
   print REGPRBUF "--------------------------------------------<BR>\n";   #dv
   close (REGPRBUF);   #dv

   $csripa = &ora_open($lda, $INSERT_USER_IP)
                   || die "failed to open $INSERT_USER_IP<BR>\n";

   &ora_bind ($csripa,     
              $record_id,     $username,    $remote_addr,   $remote_host,
              $user_os,       $user_win,    $user_browser,  $client_ident,
              $client_agent
             );

   &ora_commit($lda);
   print "<!-- after storing info in user_ip -->\n";
   &ora_close($csripa);
}

# *****************************************************
#  Fetch and print the user_ip record (DEBUG)
# *****************************************************
sub print_ip_record
{
   $csripb = &ora_open($lda, $GET_USER_IP)
                   || die "failed to open $GET_USER_IP<BR>\n";

   @ipfld = &ora_titles($csripb);
   
  (@iprec) = &ora_fetch ($csripb); 
   @uiprec = @iprec;

   print "<P><HR><P>\n";
   print "(DEBUG TABLE) The values just stored in the user_ip table are:<P>\n";
   print "<TABLE BORDER=3 >\n";
   print "<TR><TH>DB Header for Item</TH><TH>Value Stored in Database</TH></TR>\n";
   for ($i=0; $i < $#uiprec; $i++)
   {
      print "<TR><TD> $ipfld[$i] </TD><TD> $uiprec[$i] </TD></TR>\n";
   }
   print "</TABLE>\n";
   &ora_close($csripb);

}

# ***************************************************
# Print entire stored record (DEBUG printout)
# ***************************************************
sub print_stored_record
{

   print "<P><HR><P>\n";
   print "(DEBUG TABLE) The values just stored in the database are:<P>\n";
   print "<TABLE BORDER=3 >\n";
   print "<TR><TH>DB Header for Item</TH><TH>Value Stored in Database</TH></TR>\n";
   for ($i=0; $i < $#printrec; $i++)
   {
      print "<TR><TD>$reg_fldname[$i]</TD><TD>$printrec[$i]</TD></TR>\n";
   }
   print "</TABLE>\n";
   &ora_close($csrdisplay);
}

# ***************************************************
# Write ht access and password files and transfer
# ***************************************************
sub write_password_files
{
  $AUTHUSERFILE = 'AuthUserFile /root2/nadocs/private/residential/.htpasswd'; # this is the real one
# $AUTHUSERFILE = 'AuthUserFile /root2/nadocs/private/testdv/residential/.htpasswd'; # testing version not currently point to real directory

  $AUTHGROUPFILE = 'AuthGroupFile /root2/nadocs/private/residential/.htgroup';   # real file
# $AUTHGROUPFILE = 'AuthGroupFile /root2/nadocs/private/testdv/residential/.htgroup';   # test file

  $AUTHNAME = 'AuthName Carrier Residential\nAuthType Basic'; #dv

# $HTPASS = '/home/suppx1/bwm/admin/.htpasswd'; 

  &write_comment("<BR> $AUTHUSERFILE<BR>\n");
# print "<BR> $AUTHGROUPFILE<BR>\n";
# print "<BR> $AUTHNAME<BR>\n";

  $GET_RES_USERS = 
                "SELECT username, user_pw 
                   FROM user_reg
                  WHERE user_permissions LIKE '%H1%'
                  ORDER BY reg_date";

# print "<BR>$GET_RES_USERS<BR>\n";

  $csrpw = &ora_open($lda, $GET_RES_USERS) 
           || print "<BR> error in opening $GET_RES_USERS <BR>\n"; 

  $ii =0;
  while ( ($unm, $pw) = &ora_fetch($csrpw) )
  {
     $uname[$ii] = $unm;
     $passw[$ii] = $pw;
     $ii++;
  }  
  &ora_close($csrpw);
  
  &write_comment("after getting user list of $#uname users\n");

# open new htaccess file 
# ----------------------
   $pwfile="/home/suppx1/bwm/admin/userfile";  #real
#  $pwfile = "/oradata/disk4/carrier/cdata/files_test/userfile"; #test
   open (PWFILE, ">$pwfile") || warn "Couldn't open userfile\n"; 
   select PWFILE;
   print "$AUTHUSERFILE\n";
   print "$AUTHGROUPFILE\n";
   print "$AUTHNAME\n";
   print "<Limit GET POST>\n";
   print "require group res_user\n";

   print "</Limit>\n";
   close (PWFILE);
  
#  print STDOUT "<BR>after writing access file<BR>\n"; 
   select STDOUT;

# open new htgroup file 
# ----------------------
   $pgfile="/home/suppx1/bwm/admin/groupfile";  #real
#  $pgfile = "/oradata/disk4/carrier/cdata/files_test/groupfile"; #test
   open (PGFILE, ">$pgfile") || warn "Couldn't open groupfile for writing\n"; 

   for ($i =0; $i <= $#uname; $i++)
   {
      print PGFILE "res_user: $uname[$i]\n";
   }  
   close (PGFILE);
       

# open new password file 
# ----------------------
  $ppwfile="/home/suppx1/bwm/admin/passfile";  #real
# $ppwfile="/oradata/disk4/carrier/cdata/files_test/passfile";  #test
  open(HTPASS, ">$ppwfile");
  for ($i = 0; $i <= $#uname; $i++) {
     $pass = crypt("$passw[$i]","jc");
     print(HTPASS "$uname[$i]:$pass\n");
  }
  close(HTPASS);

# system("/bin/cp $pwfile  /root2/nadocs/private/residential/.htaccess");  #real
# system("/bin/cp $ppwfile /root2/nadocs/private/residential/.htpasswd");  #real
# system("/bin/cp $pgfile  /root2/nadocs/private/residential/.htgroup");  #real

  system("/bin/cp $pwfile  /root2/nadocs/private/testdv/residential/.htaccess");  #test
  system("/bin/cp $ppwfile /root2/nadocs/private/testdv/residential/.htpasswd");  #test
  system("/bin/cp $pgfile  /root2/nadocs/private/testdv/residential/.htgroup");  #test
}

# ***************************************************
# Write return page for successful registration
# ***************************************************
sub write_return_page
{

   $img  = "nao_media/register.jpg";
   print "<P><BR>\n";
   print "<UL>\n";
   print "<TABLE CELLSPACING=15 BORDER=0>\n";
   print "<TR><TD>\n";
   print "<IMG SRC=\"$docpath$img\" WIDTH=200 HEIGHT=120 BORDER=0>\n";
   print "</TD><TD ALIGN+CENTER>\n";
   print "<FONT SIZE=4>\n";
   print "<B>Thank You for <BR>Your Registration </B></FONT>\n";
   print "</TD></TR>\n";
   print "</TABLE>\n";

#  $img  = "nao_media/register.jpg";
#  print "<IMG SRC=\"$docpath$img\" WIDTH=200 HEIGHT=120 BORDER=0>\n";
#  print "<P>\n";

#  Information on next steps and downloading
# ------------------------------------------
#  $commreq = "n";
#  if ( $com_req eq "y" || $ltcom_req eq "y" || $ptac_req eq "y" )
#  {
#     $commreq = "y";
#  } 

#  if ( $res_req eq "a"  && $commreq eq "n") {&print_res_info;}
#  if ( $commreq eq "y"  && $res_req eq "n") {&print_com_info;}
#  if ( $commreq eq "y"  && $res_req eq "a") {&print_com_res_info;}


   if ( $res_req eq "a"  && $ptac_req eq "n") {&print_res_info;}
   if ( $ptac_req eq "y"  && $res_req eq "n") {&print_ptac_info;}
   if ( $ptac_req eq "y"  && $res_req eq "a") {&print_res_ptac_info;}

   if ($DEBUG) {&print_stored_record; } 
   print "<P><P>\n";
     # {&print_ip_record; }  doesn't print some values even tho there.
   print "<UL>\n";

   print "<P>\n";
   print "<I> &nbsp Click on any of the perspective buttons (above)\n";
   print " or other links (at left).</I><P>\n";
}

# ***************************************************
# Write return paragraph for res downloads 
# updated 18sep96, 23mar98, 24may98
# ***************************************************
sub print_res_info
{
#  print "<P><B>Residential Product Data Digests</B>\n";
   print "<UL>";
   print "Your registration request for Preferred Access to information \n";
   print "in the Comfort at Home Perspective has been approved.<P>\n";

   print "Your default Password will be the same as your requested User Name\n";
   print "using up to a maximum of the first eight characters.  For example:<BR>\n";
   print "<UL>\n";
   print "<TABLE>\n";
   print "<TR><TD>Requested User Name = </TD><TD><B>TotalComfort</B></TD></TR>\n";
   print "<TR><TD>Default Password = </TD><TD><B>TotalCom</B></TD></TR>\n";
   print "</TABLE>";
   print "</UL>";
  
   print "If you wish to make any changes to your registration profile, please\n";
   print "call 1-800-CARRIER.<P>\n";

   print "</UL>\n";
   print "<P>\n";
}
### start new subroutines
# ***************************************************
# Write return paragraph for ptac downloads 
# updated 23mar98
# ***************************************************
sub print_ptac_info
{
#  print "<P><B>Packaged Terminal Data Digests</B>\n";
   print "<UL>";
   print "Your registration request for Preferred Access to information \n";
   print "about Packaged Terminal Air Conditioners and Heat Pumps \n";
   print "for residential use has been approved.<P>\n";

   print "Your default Password will be the same as your requested User Name\n";
   print "using up to a maximum of the first eight characters.  For example:<BR>\n";
   print "<UL>\n";
   print "<TABLE>\n";
   print "<TR><TD>Requested User Name = </TD><TD><B>TotalComfort</B></TD></TR>\n";
   print "<TR><TD>Default Password = </TD><TD><B>TotalCom</B></TD></TR>\n";
   print "</TABLE>";
   print "</UL>";
  
   print "If you wish to make any changes to your registration profile, please\n";
   print "call 1-800-CARRIER.<P>\n";

   print "</UL>\n";
   print "<P>\n";
}

# ***************************************************
# Write return paragraph for res and ptac downloads 
# updated 23mar98
# ***************************************************
sub print_res_ptac_info
{
#  print "<P><B>Residential and Packaged Terminal Product Data Digests</B>\n";
   print "<UL>";
   print "Your registration request for Preferred Access to information \n";
   print "in the Comfort at Home Perspective has been approved.<P>\n";
   print "Your registration request for Preferred Access to information \n";
   print "about Packaged Terminal Air Conditioners and Heat Pumps \n";
   print "for residential use also has been approved.<P>\n";

   print "Your default Password will be the same as your requested User Name\n";
   print "using up to a maximum of the first eight characters.  For example:<BR>\n";
   print "<UL>\n";
   print "<TABLE>\n";
   print "<TR><TD>Requested User Name = </TD><TD><B>TotalComfort</B></TD></TR>\n";
   print "<TR><TD>Default Password = </TD><TD><B>TotalCom</B></TD></TR>\n";
   print "</TABLE>";
   print "</UL>";
  
   print "If you wish to make any changes to your registration profile, please\n";
   print "call 1-800-CARRIER.<P>\n";

   print "</UL>\n";
   print "<P>\n";
}

### end new subroutines
# ***************************************************
# Write return paragraph for com downloads 
# updated 18sep96
# ***************************************************
sub print_com_info
{
#  print "<P><B>Commercial Product Additional Information</B>\n";
   print "<UL>";
  
   print "Your registration request for Preferred Access to information \n";
   print "in the Comfort at Work Perspective is being processed.<P>\n";
  
   print "A Carrier representative will contact you regarding approval \n";
   print "and assignment of a password.<P>\n";
  
   print "If you wish to make any changes to your registration profile, please\n";
   print "call 1-800-CARRIER.<P>\n";

   print "</UL>\n";
   print "<P>\n";
}

# ***************************************************
# Write return paragraph for com + res downloads 
# updated 18sep96
# ***************************************************
sub print_com_res_info
{
   print "<UL>";

   print "Your registration request for Preferred Access to information \n";
   print "in the Comfort at Home Perspective has been approved.<P>\n";

   print "Your TEMPORARY Password will be the same as your requested User Name\n";
   print "using up to a maximum of the first eight characters.  For example:<BR>\n";
   print "<UL>\n";
   print "<TABLE>\n";
   print "<TR><TD>Requested User Name = </TD><TD><B>TotalComfort</B></TD></TR>\n";
   print "<TR><TD>Default Password = </TD><TD><B>TotalCom</B></TD></TR>\n";
   print "</TABLE>";
   print "</UL>";
  
   print "A Carrier representative will contact you regarding approval for access \n";
   print "to the Comfort at Work Perspective and the assignment of a PERMANENT.\n";
   print "password.<P>\n";
  
   print "If you wish to make any changes to your registration profile, please\n";
   print "call 1-800-CARRIER.<P>\n";

   print "</UL>";
}

# ***************************************************
# Print all data values that will be stored in db
# ***************************************************
sub print_data_values
{
# for debugging
   print "record_id (:1)= $record_id<BR>\n";
   print "user pw  (:2) = $userpw<BR>\n";
   print "username (:3) = $username<BR>\n";
   print "first name (:4) = $user_fname<BR>\n";
   print "last name (:5) = $user_lname<BR>\n";
   print "title or occupation (:6) = $user_title<BR>\n";
   print "registration status (:7) = $userstat<BR>\n";
   print "user permissions (:8) = $userpm<BR>\n";
   print "company name (:9) = $company<BR>\n";
   print "address line 1 (:10) = $address1<BR>\n";
   print "address line 2 (:11) = $address2<BR>\n";
   print "city (:12) = $city<BR>\n";
   print "state (:13) = $state<BR>\n";
   print "region (:14) = $region<BR>\n";
   print "5 digit zip_code (:15) = $zip_code5<BR>\n";
   print "4 digit zip_code (:16) = $zip_code4<BR>\n";
   print "postal_code (:17) = $postal_code<BR>\n";
   print "country (:18) = $country<BR>\n";
   print "user or company URL (:19) = $company_url<BR>\n";
   print "user phone number (:20) = $user_phone<BR>\n";
   print "user fax number (:21) = $user_fax<BR>\n";
   print "user email (:22) = $user_email<BR>\n";
   print "contact id (:23) = $contact_id<BR>\n";
   print "carrier contact (:24) = $contact_name<BR>\n";
   print "contact_company (:25) = $contact_company<BR>\n";
   print "contact_phone (:26) = $contact_phone<BR>\n";
   print "contact_fax (:27) = $contact_fax<BR>\n";
   print "contact_email (:28) = $contact_email<BR>\n";
   print "contact_location (:29) = $contact_location<BR>\n";
   print "putting on email list ok? (:30) = $email_ok<BR>\n";
   print "PTAC products selected (:31) = $ptac_req<BR>\n";
   print "LTCOM products selected (:32) = $ltcom_req<BR>\n";
   print "RES products selected (:33) = $res_req<BR>\n";
   print "COM products selected (:34) = $com_req<BR>\n";
   print "date of this registration (:35) = $reg_date<BR>\n";
   print "user phone extension (:36) = $user_phone_ext1<BR>\n";
   print "user phone numerical value (:37) = $user_phone_num<BR>\n";

}

